# node-tasks

A simple CLI for listing and executing npm tasks.

## Installation

```bash
$ pip install nodetasks
```

## Usage

![Example usage](example.gif)

## Todo

- [] Give user ability to run tasks with yarn
